@@ -2,7 +2,7 @@ package MooX::ShortHas;
 
 use strictures 2;
 
-our $VERSION = '1.172231'; # VERSION
+our $VERSION = '1.172250'; # VERSION
 
 # ABSTRACT: shortcuts for common Moo has attribute configurations
 
@@ -29,13 +29,13 @@ sub _modified_has {
 
 sub import {
     my $caller = caller;
-    my $has    = $caller->can( "has" );
+    my $has    = $caller->can( "has" ) or die "Moo not loaded in caller: $caller";
     my %mods   = (
         lazy => [qw( is lazy builder )],
         map { $_ => [ is => $_ => required => 1 ] } qw( ro rwp rw )
     );
     for my $mod ( keys %mods ) {
-        _install_coderef "$caller::$mod" => sub {
+        _install_coderef $caller. "::$mod" => sub {
             _modified_has $has, $mods{$mod}, @_;
         };
     }
@@ -53,7 +53,7 @@ MooX::ShortHas - shortcuts for common Moo has attribute configurations
 
 =head1 VERSION
 
-version 1.172231
+version 1.172250
 
 =head1 SYNOPSIS
 
